OC.L10N.register(
    "files",
    {
    "File could not be found" : "Nepavyko rasti failo",
    "Move or copy" : "Perkelti ar kopijuoti",
    "Download" : "Atsisiųsti",
    "Delete" : "Ištrinti",
    "Tags" : "Žymės",
    "Show list view" : "Rodyti sąrašo rodinį",
    "Show grid view" : "Rodyti tinklelio rodinį",
    "Home" : "Pagrindinis",
    "Close" : "Užverti",
    "Could not create folder \"{dir}\"" : "Nepavyko sukurti aplanko „{dir}“",
    "This will stop your current uploads." : "Tai sustabdys dabartinius įkėlimus.",
    "Upload cancelled." : "Įkėlimo atsisakyta.",
    "Processing files …" : "Apdorojami failai…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nepavyksta įkelti {filename}, nes tai yra katalogas arba šio failo dydis yra 0 baitų",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nepakanka laisvos vietos. Jūs bandote įkelti {size1} dydžio bylą, bet liko tik  {size2} vietos",
    "Target folder \"{dir}\" does not exist any more" : "Paskirties aplanko „{dir}“ daugiau nebėra",
    "Not enough free space" : "Trūksta laisvos vietos",
    "An unknown error has occurred" : "Įvyko nežinoma klaida",
    "File could not be uploaded" : "Nepavyko įkelti failo",
    "Uploading …" : "Įkeliama…",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} iš {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "To elemento įkėlimas nėra palaikomas",
    "Target folder does not exist any more" : "Paskirties aplanko daugiau nebėra",
    "Operation is blocked by access control" : "Operacija yra užblokuota prieigos valdymo",
    "Error when assembling chunks, status code {status}" : "Klaida surenkant dalis, klaidos kodas {status}",
    "Actions" : "Veiksmai",
    "Rename" : "Pervadinti",
    "Move" : "Perkelti",
    "Copy" : "Kopijuoti",
    "Choose target folder" : "Pasirinkite paskirties aplanką",
    "Set reminder" : "Nustatyti priminimą",
    "Edit locally" : "Redaguoti lokaliai",
    "Open" : "Atverti",
    "_Delete file_::_Delete files_" : ["Ištrinti failą","Ištrinti failus","Ištrinti failus","Ištrinti failus"],
    "Could not load info for file \"{file}\"" : "Nepavyko įkelti informacijos failui „{file}“",
    "Files" : "Failai",
    "Details" : "Išsamiau",
    "Please select tag(s) to add to the selection" : "Pasirinkite raktažodžius pridėti prie pažymėtų",
    "Apply tag(s) to selection" : "Pritaikyti raktažodžiuis pasirinktiems",
    "Select directory \"{dirName}\"" : "Pasirinkite direktoriją \"{dirName}\"",
    "Select file \"{fileName}\"" : "Pasirinkite failą \"{fileName}\"",
    "Pending" : "Laukiantis",
    "Unable to determine date" : "Nepavyksta nustatyti datos",
    "This operation is forbidden" : "Ši operacija yra uždrausta",
    "This directory is unavailable, please check the logs or contact the administrator" : "Šis katalogas neprieinamas, peržiūrėkite žurnalo įrašus arba susisiekite su administratoriumi",
    "Storage is temporarily not available" : "Saugykla yra laikinai neprieinama",
    "Could not move \"{file}\", target exists" : "Nepavyko perkelti „{file}“, toks failas jau yra",
    "Could not move \"{file}\"" : "Nepavyko perkelti „{file}“",
    "copy" : "kopija",
    "Could not copy \"{file}\", target exists" : "Nepavyko nukopijuoti \"{file}\", toks jau yra",
    "Could not copy \"{file}\"" : "Nepavyko nukopijuoti \"{file}\"",
    "Copied {origin} inside {destination}" : "Nukopijuota {origin} aplanke {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Nukopijuota {origin} ir dar {nbfiles} failus aplanke {destination}",
    "{newName} already exists" : "{newName} jau yra",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nepavyko pervadinti failo „{fileName}“, jo daugiau nebėra",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Pavadinimas „{targetName}“ jau naudojamas aplanke „{dir}“. Pasirinkite kitokį pavadinimą.",
    "Could not rename \"{fileName}\"" : "Nepavyko pervadinti failo „{fileName}“",
    "Could not create file \"{file}\"" : "Nepavyko sukurti failo „{file}“",
    "Could not create file \"{file}\" because it already exists" : "Nepavyko sukurti failo „{file}“, nes jis jau yra",
    "Could not create folder \"{dir}\" because it already exists" : "Nepavyko sukurti aplanko „{dir}“, nes jis jau yra",
    "Could not fetch file details \"{file}\"" : "Nepavyko gauti išsamesnės failo \"{file}\" informacijos",
    "Error deleting file \"{fileName}\"." : "Klaida ištrinant failą „{fileName}“.",
    "No search results in other folders for {tag}{filter}{endtag}" : "Kituose aplankuose nėra paieškos rezultatų, skirtų {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Įveskite daugiau nei du simbolius, jei norite ieškoti kituose aplankuose",
    "Name" : "Pavadinimas",
    "Size" : "Dydis",
    "Modified" : "Pakeistas",
    "_%n folder_::_%n folders_" : ["%n aplankas","%n aplankai","%n aplankų","%n aplankas"],
    "_%n file_::_%n files_" : ["%n failas","%n failai","%n failų","%n failas"],
    "{dirs} and {files}" : "{dirs} ir {files}",
    "_including %n hidden_::_including %n hidden_" : ["įskaitant %n paslėptą","įskaitant %n paslėptus","įskaitant %n paslėptų","įskaitant %n paslėptą"],
    "You do not have permission to upload or create files here" : "Neturite teisės įkalti ar kurti failus šioje vietoje",
    "_Uploading %n file_::_Uploading %n files_" : ["Įkeliamas %n failas","Įkeliami %n failai","Įkeliama %n failų","Įkeliamas %n failas"],
    "New" : "Nauja",
    "Select file range" : "Žymėti failų rėžį",
    "{used}%" : "{used}%",
    "{used} of {quota} used" : "panaudota {used} iš {quota}",
    "{used} used" : "{used} naudojama",
    "\"{name}\" is an invalid file name." : "„{name}“ yra netinkamas bylos pavadinimas.",
    "File name cannot be empty." : "Failo pavadinimas negali būti tuščias.",
    "\"/\" is not allowed inside a file name." : "Failo pavadinime simbolis „/“ draudžiamas.",
    "\"{name}\" is not an allowed filetype" : "„{name}“ nėra leidžiamas failo tipas",
    "Your storage is full, files cannot be updated or synced anymore!" : "Jūsų saugykla yra pilna, failai daugiau nebegalės būti atnaujinti ar sinchronizuoti!",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Grupės aplankas \"{mountPoint}\" yra beveik pilnas ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Išorinė saugykla \"{mountPoint}\" yra beveik pilna ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Jūsų saugykla yra beveik pilna ({usedSpacePercent}%).",
    "View in folder" : "Rodyti aplanke",
    "Path" : "Kelias",
    "_%n byte_::_%n bytes_" : ["%n baitas","%n baitai","%n baitų","%n baitų"],
    "Favorited" : "Pažymėtas mėgstamu",
    "Favorite" : "Mėgstamas",
    "New folder" : "Naujas aplankas",
    "Create new folder" : "Sukurti naują aplanką",
    "Upload file" : "Įkelti failą",
    "Recent" : "Paskiausiai naudoti",
    "Not favorited" : "Nepažymėtas mėgstamu",
    "Remove from favorites" : "Šalinti iš mėgstamų",
    "Add to favorites" : "Pridėti į mėgstamus",
    "An error occurred while trying to update the tags" : "Bandant atnaujinti žymes įvyko klaida",
    "Added to favorites" : "Pridėta į mėgstamus",
    "Removed from favorites" : "Pašalintas iš mėgstamų",
    "You added {file} to your favorites" : "Pridėjote {file} į savo mėgstamus",
    "You removed {file} from your favorites" : "Pašalinote {file} iš mėgstamų",
    "Favorites" : "Mėgstami",
    "File changes" : "Failo pakeitimai",
    "Created by {user}" : "Sukūrė {user}",
    "Changed by {user}" : "Pakeitė {user}",
    "Deleted by {user}" : "Ištrynė {user}",
    "Restored by {user}" : "Atkūrė {user}",
    "Renamed by {user}" : "Pervadino {user}",
    "Moved by {user}" : "Perkėlė {user}",
    "You created {file}" : "Jūs sukūrėte {file}",
    "You created an encrypted file in {file}" : "Sukūrėte užšifruotą failą {file}",
    "{user} created {file}" : "{user} sukūrė {file}",
    "{user} created an encrypted file in {file}" : "{user} sukūrė užšifruotą failą {file}",
    "{file} was created in a public folder" : "{file} buvo sukurtas viešajame aplanke",
    "You changed {file}" : "Jūs pakeitėte {file}",
    "You changed an encrypted file in {file}" : "Pakeitėte užšifruotą failą {file}",
    "{user} changed {file}" : "{user} pakeitė {file}",
    "{user} changed an encrypted file in {file}" : "{user} pakeitė užšifruotą failą {file}",
    "You deleted {file}" : "Jūs ištrynėte {file}",
    "You deleted an encrypted file in {file}" : "Jūs ištrynėte šifruotą failą {file}",
    "{user} deleted {file}" : "{user} ištrynė {file}",
    "{user} deleted an encrypted file in {file}" : "{user} ištrynė šifruotą failą {file}",
    "You restored {file}" : "Jūs atkūrėte {file}",
    "{user} restored {file}" : "{user} atkūrė {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Jūs pervadinote {oldfile} (paslėptas) į {newfile} (paslėptas)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Jūs pervadinote {oldfile} (paslėptas) į {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Jūs pervadinote {oldfile} į {newfile} (paslėptas)",
    "You renamed {oldfile} to {newfile}" : " {oldfile} pervadintas į {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} pervadino {oldfile} (paslėptas) į {newfile} (paslėptas)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} pervadino {oldfile} (paslėptas) į {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} pervadino {oldfile} į {newfile} (paslėptas)",
    "{user} renamed {oldfile} to {newfile}" : "{user} pervadino {oldfile} į {newfile}",
    "You moved {oldfile} to {newfile}" : "{oldfile} perkeltas į {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} perkėlė {oldfile} į {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Failas buvo pridėtas arba pašalintas iš <strong>mėgstamų</strong>",
    "A file or folder has been <strong>changed</strong>" : "Buvo <strong>pakeistas</strong> failas ar aplankas",
    "A favorite file or folder has been <strong>changed</strong>" : "Buvo <strong>pakeistas</strong> mėgstamas failas ar aplankas",
    "Upload (max. %s)" : "Įkelti (maks. %s)",
    "Accept" : "Priimti",
    "Reject" : "Atmesti",
    "Incoming ownership transfer from {user}" : "Gaunamasis nuosavybės perdavimas nuo {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Ar norite priimti {path}?\n\nPastaba: Priėmus, perdavimo procesas gali užtrukti iki 1 valandos.",
    "Ownership transfer failed" : "Nuosavybės perdavimas nepavyko",
    "Your ownership transfer of {path} to {user} failed." : "Nepavyko perduoti jūsų {path} nuosavybės naudotojui {user}.",
    "The ownership transfer of {path} from {user} failed." : "{path} nuosavybės perdavimas iš naudotojo {user} nepavyko.",
    "Ownership transfer done" : "Nuosavybės perdavimas atliktas",
    "Your ownership transfer of {path} to {user} has completed." : "Jūsų {path} nuosavybės perdavimas naudotojui {user} užbaigtas.",
    "The ownership transfer of {path} from {user} has completed." : "{path} nuosavybės perdavimas iš naudotojo {user} užbaigtas.",
    "in %s" : "per %s",
    "File Management" : "Failų tvarkymas",
    "You don’t have permission to upload or create files here" : "Jūs neturite leidimo čia įkelti arba kurti failus",
    "Rename file" : "Pervadinti failą",
    "File name" : "Failo pavadinimas",
    "Folder name" : "Aplanko pavadinimas",
    "Download file {name}" : "Atsisiųsti failą {name}",
    "{newName} already exists." : "{newName} jau yra.",
    "Name cannot be empty" : "Pavadinimas negali būti tuščias",
    "List of files and folders." : "Failų ir aplankų sąrašas.",
    "File not found" : "Failas nerastas",
    "Storage informations" : "Informacija apie saugyklą",
    "Your storage is full, files can not be updated or synced anymore!" : "Jūsų saugykla pilna, failai daugiau nebegali būti atnaujinti arba sinchronizuojami!",
    "Create" : "Sukurti",
    "Transfer ownership of a file or folder" : "Perduoti failo ar aplanko nuosavybę",
    "Choose file or folder to transfer" : "Pasirinkti norimą perduoti failą ar aplanką",
    "Change" : "Keisti",
    "New owner" : "Naujasis savininkas",
    "Choose a file or folder to transfer" : "Pasirinkite norimą perduoti failą ar aplanką",
    "Transfer" : "Perduoti",
    "Transfer {path} to {userid}" : "Perduoti {path} naudotojui {userid}",
    "Invalid path selected" : "Pasirinktas neteisingas kelias",
    "Unknown error" : "Nežinoma klaida",
    "Ownership transfer request sent" : "Nuosavybės perdavimo užklausa išsiųsta",
    "No files in here" : "Čia failų nėra",
    "Upload some content or sync with your devices!" : "Įkelkite failus arba sinchronizuokite su savo įrenginiais!",
    "Go back" : "Grįžti",
    "Share" : "Bendrinti",
    "Shared by link" : "Bendrinama pagal nuorodą",
    "Shared" : "Bendrinama",
    "Switch to list view" : "Perjungti į sąrašo rodinį",
    "Files settings" : "Failų nustatymai",
    "Show hidden files" : "Rodyti paslėptus failus",
    "Crop image previews" : "Apkirpti paveikslų peržiūras",
    "Additional settings" : "Papildomi nustatymai",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "Kopijuoti į iškarpinę",
    "Use this address to access your Files via WebDAV" : "Naudokite šį adresą norėdami pasiekti failus per WebDAV",
    "Clipboard is not available" : "Iškarpinė neprieinama",
    "Unable to change the favourite state of the file" : "Nepavyksta pakeisti failo Lankomiausiųjų būsenos",
    "Error while loading the file data" : "Klaida įkeliant failo duomenis",
    "Pick a template for {name}" : "Pasirinkite šabloną, skirtą {name}",
    "Create a new file with the selected template" : "Sukurti naują failą naudojant pasirinktą šabloną",
    "Creating file" : "Sukuriamas failas",
    "Unable to create new file from template" : "Nepavyko sukurti naujo failo iš šablono",
    "Delete permanently" : "Ištrinti negrįžtamai",
    "Cancel" : "Atsisakyti",
    "The file does not exist anymore" : "Failo daugiau nebėra",
    "Copy to {target}" : "Kopijuoti į {target}",
    "Move to {target}" : "Perkelti į {target}",
    "Could not copy {file}. {message}" : "Nepavyko nukopijuoti {file}. {message}",
    "Could not move {file}. {message}" : "Nepavyko perkelti {file}. {message}",
    "Filename" : "Failo pavadinimas",
    "Unable to initialize the templates directory" : "Nepavyko inicijuoti šablonų katalogo",
    "Templates" : "Šablonai",
    "No favorites yet" : "Kol kas nėra mėgstamų",
    "Files and folders you mark as favorite will show up here" : "Čia bus rodomi failai ir aplankai, kuriuos pažymėsite kaip mėgstamus",
    "All files" : "Visi failai",
    "No entries found in this folder" : "Nerasta įrašų šiame aplanke",
    "Select all" : "Pažymėti viską",
    "Upload too large" : "Įkėlimui failas per didelis",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Bandomų įkelti failų dydis viršija maksimalų, šiame serveryje leidžiamų įkelti failų dydį.",
    "Text file" : "Tekstinis failas",
    "New text file.txt" : "Naujas tekstinis failas.txt",
    "Direct link was copied (only works for users who have access to this file/folder)" : "Tiesioginė nuoroda buvo nukopijuota (veikia tik naudotojams, turintiems prieigą prie šio failo/aplanko)",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopijuoti tiesioginę nuorodą (veiks tik naudotojams, turintiems prieigą prie šio failo/aplanko)",
    "You can only favorite a single file or folder at a time" : "Vienu metu galite pažymėti mėgstamu tik vieną failą ar aplanką",
    "\"remote user\"" : "„nuotolinis naudotojas“",
    "Search users" : "Ieškoti naudotojų",
    "Toggle grid view" : "Rodyti tinkleliu",
    "Deleted files" : "Ištrinti failai",
    "Shares" : "Viešiniai",
    "Shared with others" : "Bendrinama su kitais",
    "Shared with you" : "Bendrinama su jumis",
    "Deleted shares" : "Ištrinti viešiniai",
    "Pending shares" : "Laukiantys viešiniai",
    "This file has the tag {tag}" : "Šis failas turi žymą {tag}",
    "Choose" : "Pasirinkite",
    "Add" : "Pridėti"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
